/*
 * Evaluation timer functions.  The evaluation timer provides the main event timing
 * for other module evaluation.  It provides two timing related flags that indicate
 * a rapid and slow events.  The rapid event fires every TIMER_INIT uSec.  The slow
 * event fires every second.
 *
 * The EvalTimer call should be the first Eval made each time through the main event loop.
 */
#include <TimerOne.h>

//
// Evaluation timer constants and variables
//   Timer sets the evaluation period of 25 mSec using Timer1 functionality
//   TIMER_INIT is specified in units of uSec
//
#define SEC_TIMER_TO (1000000 / TIMER_INIT)
boolean isrTick;
int secTimer;
 
void InitTimer() {
  // Initialize TIMER1 for interrupts
  Timer1.initialize(TIMER_INIT);
  Timer1.attachInterrupt(Timer1ISR);
  
  // Initialize variables
  isrTick = false;
  timerTick = false;
  timerSecTick = false;
  secTimer = SEC_TIMER_TO;
}


// The Timer should be the first module evaluated each loop
void EvalTimer() {
  // Flags will be set if necessary
  timerTick = false;
  timerSecTick = false;
  
  // Look for timer expiration
  if (isrTick) {
    isrTick = false;
    timerTick = true;
    
    if (--secTimer == 0) {
      secTimer = SEC_TIMER_TO;
      timerSecTick = true;
    }
  }
}


// TIMER1 ISR
void Timer1ISR()
{
  isrTick = true;
}
